# Introduction
This package focuses on model parallelism training jobs with two types: tensor and pipeline. Source code is published on PyPI as [DeTrain package](https://pypi.org/project/detrain/)
# Commands
- For local development: ```pip install -e .```
- To publish to pypi:
    - ```python3 -m build```
    - ```python3 -m twine upload dist/*```

